summaryrefslogtreecommitdiffstats
path: root/akregator/src/librss/loader.h
diff options
context:
space:
mode:
Diffstat (limited to 'akregator/src/librss/loader.h')
-rw-r--r--akregator/src/librss/loader.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/akregator/src/librss/loader.h b/akregator/src/librss/loader.h
index 59f47c9c..2129bc79 100644
--- a/akregator/src/librss/loader.h
+++ b/akregator/src/librss/loader.h
@@ -211,8 +211,8 @@ namespace RSS
*
* \code
* Loader *loader = Loader::create();
- * connect(loader, TQT_SIGNAL(loadingComplete(Loader *, Document, Status)),
- * this, TQT_SLOT(slotLoadingComplete(Loader *, Document, Status)));
+ * connect(loader, TQT_SIGNAL(loadingComplete(Loader *, Document, tqStatus)),
+ * this, TQT_SLOT(slotLoadingComplete(Loader *, Document, tqStatus)));
* loader->loadFrom("http://www.blah.org/foobar.rdf", new FileRetriever);
* \endcode
*
@@ -236,7 +236,7 @@ namespace RSS
* 'slotLoadingComplete' method might look like this:
*
* \code
* void MyClass::slotLoadingComplete(Loader *loader, Document doc, Status status)
* {
* // Note that Loader::~Loader() is private, so you cannot delete Loader instances.
* // You don't need to do that anyway since Loader instances delete themselves.
@@ -322,9 +322,9 @@ namespace RSS
* the case if you intend to call getPixmap() on Document::image()!
* @param status A status byte telling whether there were any problems
* while retrieving or parsing the data.
- * @see Document, Status
+ * @see Document, tqStatus
*/
- void loadingComplete(Loader *loader, Document doc, Status status);
+ void loadingComplete(Loader *loader, Document doc, tqStatus status);
private slots:
void slotRetrieverDone(const TQByteArray &data, bool success);
@@ -236,7 +236,7 @@ namespace RSS
*
* \code
- * void MyClass::slotLoadingComplete(Loader *loader, Document doc, Status status)
+ * void MyClass::slotLoadingComplete(Loader *loader, Document doc, tqStatus status)
* {
* // Note that Loader::~Loader() is private, so you cannot delete Loader instances.